#!/usr/bin/env sh
#
# Copyright (c) 2010 Jonathan Purnell 
# 
# This file is part of SSDE-Cluster.
# 
# SSDE-Cluster is free software and distributed under the terms of the 
# GNU General Public License; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# SSDE-Cluster is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with SSDE-Cluster, named COPYING.  If not, see <http://www.gnu.org/licenses/>.
# 
# 
# SSDE-Cluster script by Jonathan Purnell
#
# This script provides a wrapper to the three programs that allow an 
# undirected connected weighted graph to be clustered into overlapping
# clusters. 
# 
# Parameters: (further details can be found in the documentation for each program called)
#
# node names file - contains the names and number of neighbors for each node
# graph file - contains all the edges and their weights
# num of clusters - number of clusters to find in the graph
# cov. type - indicates the type of covariance matrix approximation to use in fittng the GMM
# init. type - indicates the method of initializing the clusters in fitting the GMM
# cluster method - indicates the method of clustering the graph (metric-based or avg. assignment)
# EM iters - number of EM iterations in fitting the GMM
# lambda - the parameter for the cluster method

# check all the params are available
if [ $# != 8 ] 
then
    echo "Usage: SSDE-Cluster <node names file> <graph file> <num of clusters> <cov. type> <init. type> <cluster method> <EM iters> <lambda>";
    exit;
fi

# make sure the files exist
if [ ! -e $1 ] 
then
    echo "Node Names File doesn't exist: $1";
    exit;
fi

if [ ! -e $2 ] 
then
    echo "Graph File doesn't exist: $2";
    exit;
fi

# Call the three programs

# Embed
echo "Embedding data"
./SSDE $1 $2 run 1 5

# Model
echo "Modeling data"
echo "./sim $8 $3 $4 $5 final_coords.txt $1"
./sim $8 $3 $4 $5 final_coords.txt $1


# Cluster
echo "Clustering data"
echo "./Cluster $1 $2 $3 $6 $7"
./Cluster $1 $2 $3 $6 $7

echo "SSDE-Cluster done"